@@ -21,6 +21,8 @@ from .const import (
     FSR_ENDPOINT_SKILLS,
     FSR_ENDPOINT_DUTY_STANDBY_FUNCTIONS,
     FSR_ENDPOINT_DUTY_STANDBY_FUNCTION,
+    FSR_ENDPOINT_INCIDENT_RESPONSES,
+    FSR_ENDPOINT_INCIDENTS,
 )
 from .errors import FireServiceRotaError, InvalidAuthError, ExpiredTokenError, InvalidTokenError
 
@@ -128,6 +130,32 @@ class FireServiceRota(object):
         return response
 
 
+    def set_incident_response(self, id, status):
+        """Set incident response for one incident."""
+
+        url = FSR_ENDPOINT_INCIDENT_RESPONSES.format(id)
+        if status:
+            json = {'status': 'acknowledged'}
+        else:
+            json = {'status': 'rejected'}
+
+        self._request('POST', endpoint=url, log_msg_action='set incident response', params=json, auth_request=False)
+        
+
+    def get_incident_response(self, id):
+        """Get status of incident response for one incident."""
+
+        url = FSR_ENDPOINT_INCIDENTS.format(id)
+
+        response = self._request('GET', endpoint=url, log_msg_action='get incident response', auth_request=False)
+
+        for r in response['incident_responses']:
+           if self._user['id'] == r['user_id']:
+              return r['status']
+
+        return 'unknown'
+
+
     def get_availability(self):
         """Get user availablity."""
 
